import { ToastrService } from './../../../node_modules/ngx-toastr/toastr/toastr.service';
import { AddressService } from './../shared/services/business/addressService';
import { BusinessService } from './../shared/services/business/businessService';
import { ValidationHelper } from './../shared/helpers/validationHelper';
import { Component, Input, OnChanges } from '@angular/core';
import {
  FormControl,
  Validators,
  FormBuilder,
  FormGroup,
  FormsModule,
  ReactiveFormsModule,
  FormArray
} from '@angular/forms';
import { enumSelector } from './../shared/helpers/enumSelector';
import { IndustryEnum } from './../shared/enums/IndustryEnum';
import { BusinessSizeEnum } from './../shared/enums/BusinessSizeEnum';
import { GeneralHelper } from './../shared/helpers/generalHelper';
import { addressModel } from './../shared/models/general/addressesModel';
import { businessModel } from './../shared/models/business/businessModel';
import { promise } from 'protractor';
import { NotificationService } from '@app/shared/services/general/notification.Service';

const EMAIL_REGEX = /^[a-zA-Z0-9.!#$%&’*+/=?^_`{|}~-]+@[a-zA-Z0-9-]+(?:\.[a-zA-Z0-9-]+)*$/;

@Component({
  selector: 'add-business',
  templateUrl: './add_business.html',
  styleUrls: ['./add_business.scss']
})
export class AddBusiness implements OnChanges {
  public frmAddBusiness: FormGroup;
  public industries: any;
  public sizes: any;
  @Input() business: businessModel;

  businesses: businessModel[];
  sub: any;

  constructor(
    private _fb: FormBuilder,
    private _addressService: AddressService,
    private _businessService: BusinessService /* , public toastr: ToastsManager */,
    private _notifyService: NotificationService
  ) {
    this.industries = enumSelector(IndustryEnum);
    this.sizes = enumSelector(BusinessSizeEnum);
  }

  ngOnInit() {
    this.frmAddBusiness = this._fb.group({
      name: ['', Validators.required],
      industry: [''],
      size: [''],
      comments: [''],
      addresses: this._fb.array([this._addressService.getAddressFormGroup(this._fb)])
    });
  }

  ngOnChanges() {
    this.setAddresses(this.business.addresses);
  }

  get addresses(): FormArray {
    return this.frmAddBusiness.get('addresses') as FormArray;
  }

  setAddresses(addresses: addressModel[]) {

  }

  removeAddress(i: number) {
  }

  addAddress() {
  }

  public save() {
    this.saveForm(this.frmAddBusiness.value, this.frmAddBusiness.valid);
  }

  private saveForm(model: businessModel, isValid: boolean) {
    let vhelper = new ValidationHelper();
    vhelper.validateAllFormFields(this.frmAddBusiness);
    if (!this.frmAddBusiness.valid) {
      //this.toastr.error("Please fill in all mandatory fields");
    } else {
      let generalHelper = new GeneralHelper();
      model.id = generalHelper.generateRandomNoReturnNumber(6).toString();
      this._businessService
        .saveBusiness(model)
        .then(() => {
          alert('Success');
          this._notifyService.showWarning('Success', 'It Added');
          this.frmAddBusiness.reset();
          event.preventDefault();
        })
        .catch(() => {
          alert('Error');
        });
    }
  }
}
