import { PluginModel } from './../../shared/models/plugins/pluginModel';
import { RibbonItem } from '../../shared/models/plugins/RibbonItem';
import { RibbonService } from './../../shared/services/navigation/ribbonService';
import { EJComponents } from 'ej-angular2/src';
import { Router } from '@angular/router';
import { Component, ComponentFactoryResolver, ViewContainerRef, ViewChild, AfterViewInit } from '@angular/core';

@Component({
  selector: 'nav',
  templateUrl: './ribbon.component.html',
  styleUrls: ['./ribbon.component.scss']
})
export class RibbonComponent implements AfterViewInit {
  @ViewChild('new_business') newBusinessButton: EJComponents<ej.Button, any>;
  @ViewChild('ribbonGrid') ribbon: EJComponents<ej.Ribbon, any>;

  constructor(
    private router: Router,
    private componentFactory: ComponentFactoryResolver,
    private viewContainerRef: ViewContainerRef,
    private _RibbonService: RibbonService
  ) {}

  defaults = { type: 'button', width: '60', height: '70' };
  buttonSettings = { contentType: 'imageonly', imagePosition: 'imagetop', prefixIcon: 'e-ribbon e-icon e-new' };
  tabHome = [
    {
      text: 'General',
      alignType: 'rows',
      content: [
        {
          groups: [
            {
              id: 'save',
              text: 'Save',
              toolTip: 'Save',
              buttonSettings: {
                width: 60,
                prefixIcon: 'e-icon e-ribbon e-save',
                contentType: ej.ContentType.TextAndImage,
                imagePosition: ej.ImagePosition.ImageTop
              }
            }
          ],
          defaults: { type: 'button', width: '50', height: '70', isBig: 'true' }
        }
      ]
    },
    {
      text: 'New',
      alignType: 'rows',
      content: [
        {
          groups: [
            {
              id: 'new_business',
              text: 'Business',
              toolTip: 'Add New Business',
              buttonSettings: {
                width: 60,
                height: 70,
                prefixIcon: '',
                contentType: ej.ContentType.TextAndImage,
                imagePosition: ej.ImagePosition.ImageTop
              }
            },
            {
              id: 'new_contact',
              text: 'Contact',
              toolTip: 'Add New Contact to Business',
              buttonSettings: {
                width: 60,
                prefixIcon: 'hs-new-contact-to-business',
                contentType: ej.ContentType.TextAndImage,
                imagePosition: ej.ImagePosition.ImageTop
              }
            }
          ],
          defaults: { type: 'button', width: '50', height: '70', isBig: 'true' }
        }
      ]
    },
    {
      text: 'Clipboard',
      alignType: 'columns',
      enableGroupExpander: 'true',
      content: [
        {
          groups: [
            {
              id: 'paste',
              text: 'Paste',
              toolTip: 'Paste',
              buttonSettings: {
                contentType: 'imageonly',
                imagePosition: 'imagetop',
                prefixIcon: 'e-ribbon e-icon e-ribbonpaste'
              }
            }
          ],
          defaults: { type: 'button', width: '50', height: '70', isBig: 'true' }
        },
        {
          groups: [
            {
              id: 'cut',
              text: 'Cut',
              toolTip: 'Cut',
              buttonSettings: {
                contentType: 'textandimage',
                prefixIcon: 'e-ribbon e-icon e-ribboncut'
              }
            },
            {
              id: 'clear',
              text: 'Clear',
              toolTip: 'Clear All',
              buttonSettings: { contentType: 'textandimage', prefixIcon: 'e-ribbon e-icon clearAll' }
            },
            {
              id: 'copy',
              text: 'Copy',
              toolTip: 'Copy',
              buttonSettings: { contentType: 'textandimage', prefixIcon: 'e-ribbon e-icon e-ribboncopy' }
            }
          ],
          defaults: { type: 'button', width: '60', height: '25', isBig: 'false' }
        }
      ]
    },
    {
      text: 'Font',
      alignType: 'rows',
      content: [
        {
          groups: [
            {
              id: 'bold',
              toolTip: 'Bold',
              type: 'togglebutton',
              toggleButtonSettings: {
                contentType: 'imageonly',
                defaultText: 'Bold',
                activeText: 'Bold',
                defaultPrefixIcon: 'e-ribbon e-icon bold',
                activePrefixIcon: 'e-ribbon e-icon bold'
              }
            },
            {
              id: 'italic',
              toolTip: 'Italic',
              type: 'togglebutton',
              toggleButtonSettings: {
                contentType: 'imageonly',
                defaultText: 'Italic',
                activeText: 'Italic',
                defaultPrefixIcon: 'e-ribbon e-icon e-ribbonitalic',
                activePrefixIcon: 'e-ribbon e-icon e-ribbonitalic'
              }
            },
            {
              id: 'underline',
              toolTip: 'Underline',
              type: 'togglebutton',
              toggleButtonSettings: {
                contentType: 'imageonly',
                defaultText: 'Underline',
                activeText: 'Underline',
                defaultPrefixIcon: 'e-ribbon e-icon e-ribbonunderline',
                activePrefixIcon: 'e-ribbon e-icon e-ribbonunderline'
              }
            }
          ]
        }
      ]
    },
    {
      text: 'Actions',
      alignType: 'rows',
      content: [
        {
          groups: [
            {
              id: 'undo',
              text: 'Undo',
              toolTip: 'Undo',
              buttonSettings: {
                contentType: 'textandimage',
                imagePosition: 'imagetop',
                prefixIcon: 'e-ribbon e-icon e-undo'
              }
            },
            {
              id: 'redo',
              text: 'Redo',
              toolTip: 'Redo',
              buttonSettings: {
                contentType: 'textandimage',
                imagePosition: 'imagetop',
                prefixIcon: 'e-ribbon e-icon e-redo'
              }
            }
          ],
          defaults: { type: 'button', width: '40', height: '70', isBig: 'true' }
        }
      ]
    },
    {
      text: 'View',
      alignType: 'rows',
      content: [
        {
          groups: [
            {
              id: 'zoomin',
              text: 'Zoom In',
              toolTip: 'Zoom In',
              buttonSettings: {
                contentType: 'textandimage',
                imagePosition: 'imagetop',
                prefixIcon: 'e-ribbon e-icon e-zoomin'
              }
            },
            {
              id: 'zoomout',
              text: 'Zoom Out',
              toolTip: 'Zoom Out',
              buttonSettings: {
                contentType: 'textandimage',
                imagePosition: 'imagetop',
                prefixIcon: 'e-ribbon e-icon e-zoomout'
              }
            },
            {
              id: 'fullscreen',
              text: 'Full Screen',
              toolTip: 'Full Screen',
              buttonSettings: {
                contentType: 'textandimage',
                imagePosition: 'imagetop',
                prefixIcon: 'e-ribbon e-icon e-fullscreen'
              }
            }
          ],
          defaults: { type: 'button', width: '73', height: '70', isBig: 'true' }
        }
      ]
    }
  ];

  handleRibbonEvent(args: any) {
    let tabName = undefined;
    let component = undefined;

    var id = args.target.id.replace('Default_', '');

    switch (id) {
      case 'save':
        this.ribbon.widget.addTab('Tab2', []);
        break;
      default:
        break;
    }

    // show tab
    if (tabName) {
    }
  }

  ngAfterViewInit() {
  
  }

  private AddItemFromConfig(config: PluginModel) {
    this.AddItem(
      config.Config.PluginConfig.RibbonItem.Id,
      config.Config.PluginConfig.RibbonItem.TextToDisplay,
      null,
      null,
      config.Config.PluginConfig.RibbonItem.TabIndex,
      config.Config.PluginConfig.RibbonItem.GroupIndex
    );

    config.Config.PluginConfig.Existing.forEach((x: RibbonItem) => {
      this.AddItem(x.Id, x.TextToDisplay, x.CssClass, x.Image, x.TabIndex, x.GroupIndex);
    });
  }

  private AddItem(
    id: string,
    TextToDisplay: string,
    CssClass: string,
    Image: string,
    TabIndex: number,
    GroupIndex: number
  ) {
    var content = { id: id, text: TextToDisplay };
    this.ribbon.widget.addTabGroupContent(TabIndex, GroupIndex, content);
  }
}
